@@ -248,19 +248,19 @@ class AddIKEPolicyAction(workflows.Action):
         super(AddIKEPolicyAction, self).__init__(request, *args, **kwargs)
 
         auth_algorithm_choices = [
-            ("sha1", "sha1"),
-            ('sha256', _('sha256')),
-            ('sha384', _('sha384')),
-            ('sha512', _('sha512')),
+            ("sha1", "SHA-1"),
+            ('sha256', _('SHA-256')),
+            ('sha384', _('SHA-384')),
+            ('sha512', _('SHA-512')),
         ]
         self.fields['auth_algorithm'].choices = auth_algorithm_choices
         # Currently this field has only one choice, so mark it as readonly.
         self.fields['auth_algorithm'].widget.attrs['readonly'] = True
 
-        encryption_algorithm_choices = [("3des", "3des"),
-                                        ("aes-128", "aes-128"),
-                                        ("aes-192", "aes-192"),
-                                        ("aes-256", "aes-256")]
+        encryption_algorithm_choices = [("3des", "3DES"),
+                                        ("aes-128", "AES-128"),
+                                        ("aes-192", "AES-192"),
+                                        ("aes-256", "AES-256")]
         self.fields[
             'encryption_algorithm'].choices = encryption_algorithm_choices
         self.fields['encryption_algorithm'].initial = "aes-128"
@@ -355,10 +355,10 @@ class AddIPsecPolicyAction(workflows.Action):
         super(AddIPsecPolicyAction, self).__init__(request, *args, **kwargs)
 
         auth_algorithm_choices = [
-            ("sha1", "sha1"),
-            ('sha256', _('sha256')),
-            ('sha384', _('sha384')),
-            ('sha512', _('sha512')),
+            ("sha1", "SHA-1"),
+            ('sha256', _('SHA-256')),
+            ('sha384', _('SHA-384')),
+            ('sha512', _('SHA-512')),
         ]
         self.fields['auth_algorithm'].choices = auth_algorithm_choices
         # Currently this field has only one choice, so mark it as readonly.
@@ -368,10 +368,10 @@ class AddIPsecPolicyAction(workflows.Action):
                                       ("transport", "transport")]
         self.fields['encapsulation_mode'].choices = encapsulation_mode_choices
 
-        encryption_algorithm_choices = [("3des", "3des"),
-                                        ("aes-128", "aes-128"),
-                                        ("aes-192", "aes-192"),
-                                        ("aes-256", "aes-256")]
+        encryption_algorithm_choices = [("3des", "3DES"),
+                                        ("aes-128", "AES-128"),
+                                        ("aes-192", "AES-192"),
+                                        ("aes-256", "AES-256")]
         self.fields[
             'encryption_algorithm'].choices = encryption_algorithm_choices
         self.fields['encryption_algorithm'].initial = "aes-128"
@@ -387,9 +387,9 @@ class AddIPsecPolicyAction(workflows.Action):
         self.fields['pfs'].choices = pfs_choices
         self.fields['pfs'].initial = "group5"
 
-        transform_protocol_choices = [("esp", "esp"),
-                                      ("ah", "ah"),
-                                      ("ah-esp", "ah-esp")]
+        transform_protocol_choices = [("esp", "ESP"),
+                                      ("ah", "AH"),
+                                      ("ah-esp", "AH-ESP")]
         self.fields['transform_protocol'].choices = transform_protocol_choices
 
     class Meta(object):
@@ -583,7 +583,15 @@ class AddIPsecSiteConnectionOptionalAction(workflows.Action):
                     "is IPv6."))
     dpd_action = forms.ThemableChoiceField(
         label=_("Dead peer detection actions"),
-        required=False)
+        required=False,
+        help_text=_("1. Hold - ends the connection and waits for the remote "
+                    "side to reconnect. 2. Clear - drops the connection and "
+                    "does not try to bring it back. 3. Disabled - turns off "
+                    "dead peer detection entirely, so no active checks are "
+                    "sent. 4. Restart - starts trying to reconnect as soon "
+                    "as the timeout happens. 5. Restart-by-peer - the "
+                    "connection is re-established because the remote peer "
+                    "initiated the restart after a timeout or failure."))
     dpd_interval = forms.IntegerField(
         min_value=1, label=_("Dead peer detection interval"),
         initial=30,
@@ -595,7 +603,12 @@ class AddIPsecSiteConnectionOptionalAction(workflows.Action):
         required=False,
         help_text=_("Valid integer greater than the DPD interval"))
     initiator = forms.ThemableChoiceField(
-        label=_("Initiator state"), required=False)
+        label=_("Initiator state"), required=False,
+        help_text=_("Defines which side of the connection is responsible "
+                    "for initiating. Bi-directional - the tunnel can be "
+                    "established by either endpoint. Response-only - waits "
+                    "until the remote peer sends a request, and only then "
+                    "the connection is established."))
     admin_state_up = forms.BooleanField(
         label=_("Enable Admin State"),
         help_text=_("The state of IPsec site connection to start in. "
